/* $Id: OrganizationManager.java,v 1.1 2007/11/29 06:01:12 konno Exp $
 *
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow Core.
 * 
 *  Nautica Workflow Core is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow Core is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Nautica Workflow Core; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.workflow.security;

import jp.co.argo21.nautica.workflow.wfmc.WorkflowSecurityException;


/**
 * 本ワークフローシステム運用基盤利用されるインタフェースを規定する。
 * OrganizationManagerは、組織管理関連の各種APIを定義する。
 * 実際には、任意の組織管理システムを利用するために、
 * このインタフェースを利用した具体実装を用意しなければならない。
 *
 * @author  nito(Argo 21, Corp.)
 * @version $Revision: 1.1 $
 * @since   Nautica Workflow 1.0
 */
public interface OrganizationManager {

	/**
	 * oidに対応する組織を返す。
	 * oidに対応する組織が存在しない場合は null を返す。
	 *
	 * @param oid 組織ID
	 * @return 組織単位
	 * @throws InvalidRoleException 指定された組織が有効でない場合
	 * @throws WorkflowSecurityException その他のセキュリティ例外
	 */
	public Organization getOrganization(String oid)
	throws InvalidOrganizationException, WorkflowSecurityException;

	/**
	 * 組織に属しているユーザの一覧を返す。
	 * ユーザが存在しない場合は空の配列を返す。
	 *
	 * @param org 組織単位
	 * @return ユーザ一覧
	 * @throws InvalidRoleException 指定された組織が有効でない場合
	 * @throws WorkflowSecurityException その他のセキュリティ例外
	 */
	public User[] getAssignedUser(Organization org)
	throws InvalidOrganizationException, WorkflowSecurityException;

	/**
	 * ユーザの所属する組織を返す。
	 * 組織が存在しない場合は空の配列を返す。
	 * 
	 * @param user ユーザ
	 * @return 組織一覧
	 * @throws InvalidRoleException 指定されたユーザが有効でない場合
	 * @throws WorkflowSecurityException その他のセキュリティ例外
	 */
	public Organization[] getOrganizationByUser(User user)
	throws InvalidUserException, WorkflowSecurityException;
	
	/**
	 * 該当組織の上位組織を返す。
	 * 上位組織が存在しない場合は null を返す。
	 *
	 * @param org 組織単位
	 * @return 上位組織
	 * @throws InvalidOrganizationException 指定された組織が有効でない場合
	 * @throws WorkflowSecurityException その他のセキュリティ例外
	 */
	public Organization getHigherOrganization(Organization org)
	throws InvalidOrganizationException, WorkflowSecurityException;
}
