package jp.co.argo21.nautica.workflow.soap;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.xml.ws.RequestWrapper;
import javax.xml.ws.ResponseWrapper;

import jp.co.argo21.nautica.workflow.omg.WorkflowException;
import jp.co.argo21.nautica.workflow.soap.message.Filter;
import jp.co.argo21.nautica.workflow.soap.message.ProcDef;
import jp.co.argo21.nautica.workflow.soap.message.ProcessDefinitionState;
import jp.co.argo21.nautica.workflow.wfmc.InvalidFilterException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidProcessDefinitionException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidSessionException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidStateException;
import jp.co.argo21.nautica.workflow.wfmc.TransitionNotAllowedException;

@WebService(name="DefinitionRepository",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
public interface DefinitionRepository {
	
	/**
	 * 指定された定義の登録処理を行い、エンジンに認識させる。
	 *
	 * @param session セッションID
	 * @param name ワークフロー定義名
	 * @param path ワークフロー定義の相対パス
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws WorkflowException プロセスインスタンスIDが有効でない場合
	 */
	@WebMethod(operationName = "registerDefinition")
	@RequestWrapper(localName = "registerDefinition", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.RegisterDefinition")   
	public void registerDefinition(@WebParam(name = "session") String session, @WebParam(name = "name") String name, @WebParam(name = "path") String path) throws InvalidSessionException, WorkflowException;

	/**
	 * 条件にマッチしたプロセス定義一覧を返す。
	 *
	 * @param session セッションID
	 * @param filter 検索用フィルター
	 * @return 検索されたプロセス定義概要の配列
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@WebMethod(operationName = "getProcessDefinitions")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getProcessDefinitions", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetProcessDefinitions")
	@ResponseWrapper(localName = "getProcessDefinitionsResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetProcessDefinitionsResponse")   
	public ProcDef[] getProcessDefinitions(@WebParam(name = "session") String session, @WebParam(name = "filter") Filter[] filter) throws InvalidSessionException, InvalidFilterException;
	
	/**
	 * プロセス定義IDで特定された定義の現在の状態から遷移可能な
	 * プロセス定義状態一覧を返す。
	 *
	 * @param session セッションID
	 * @param pdid プロセス定義ID
	 * @return プロセス定義状態の配列
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessDefinitionException 指定されたプロセス定義IDが有効でない場合
	 */
	@WebMethod(operationName = "getProcessDefinitionStates")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getProcessDefinitionStates", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetProcessDefinitionStates")
	@ResponseWrapper(localName = "getProcessDefinitionStatesResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetProcessDefinitionStatesResponse")   
	public ProcessDefinitionState[] getProcessDefinitionStates(@WebParam(name = "session") String session, @WebParam(name = "pdid") String pdid) throws InvalidSessionException, InvalidProcessDefinitionException;
	
	/**
	 * プロセス定義状態を変更する。
	 *
	 * @param session セッションID
	 * @param pdid プロセス定義ID
	 * @param state プロセス定義状態
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessDefinitionException 指定されたプロセス定義IDが有効でない場合
	 * @throws InvalidStateException 指定された状態が有効でない場合
	 * @throws TransitionNotAllowedException 状態の変更が許可されていない場合
	 */
	@WebMethod(operationName = "changeProcessDefinitionState")
	@RequestWrapper(localName = "changeProcessDefinitionState", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.ChangeProcessDefinitionState")   
	public void changeProcessDefinitionState(@WebParam(name = "session") String session, @WebParam(name = "pdid") String pdid, @WebParam(name = "state") ProcessDefinitionState state) throws InvalidSessionException, InvalidProcessDefinitionException, InvalidStateException, TransitionNotAllowedException;
	
}