package jp.co.argo21.nautica.workflow.soap;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.xml.ws.RequestWrapper;
import javax.xml.ws.ResponseWrapper;

import jp.co.argo21.nautica.workflow.omg.WorkflowException;
import jp.co.argo21.nautica.workflow.soap.message.Organization;
import jp.co.argo21.nautica.workflow.soap.message.User;
import jp.co.argo21.nautica.workflow.wfmc.WorkflowSecurityException;

@WebService(name="OrganizationManager",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
public interface OrganizationManager {

	/**
	 * oidに対応する組織を返す。
	 *
	 * @param oid 組織ID
	 * @return 組織単位
	 * @throws ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getOrganization")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getOrganization", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetOrganization")
	@ResponseWrapper(localName = "getOrganizationResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetOrganizationResponse")   
	public Organization getOrganization(@WebParam(name = "oid") String oid) throws ServiceAccessorException, WorkflowException;
	
	/**
	 * 組織に属しているユーザの一覧を返す。
	 *
	 * @param org 組織単位
	 * @return ユーザ一覧
	 * @throws ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getAssignedUser")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getAssignedUser", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetAssignedUser")
	@ResponseWrapper(localName = "getAssignedUserResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetAssignedUserResponse")   
	public User[] getAssignedUser(@WebParam(name = "org") Organization org) throws ServiceAccessorException, WorkflowException;
	
	/**
	 * ユーザの所属する組織を返す。
	 * 
	 * @param user ユーザ
	 * @return 組織一覧
	 * @throws WorkflowException 
	 * @throws WorkflowSecurityException その他のセキュリティ例外
	 */
	@WebMethod(operationName = "getOrganizationByUser")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getOrganizationByUser", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetOrganizationByUser")
	@ResponseWrapper(localName = "getOrganizationByUserResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetOrganizationByUserResponse")   
	public Organization[] getOrganizationByUser(@WebParam(name = "user") User user) throws ServiceAccessorException, WorkflowException;
	
	/**
	 * 該当組織の上位組織を返す。
	 *
	 * @param org 組織単位
	 * @return 上位組織
	 * ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getHigherOrganization")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getHigherOrganization", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetHigherOrganization")
	@ResponseWrapper(localName = "getHigherOrganizationResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetHigherOrganizationResponse")   
	public Organization getHigherOrganization(@WebParam(name = "org") Organization org) throws ServiceAccessorException, WorkflowException;
	
}