package jp.co.argo21.nautica.workflow.soap;

import javax.annotation.Resource;
import javax.jws.WebService;
import javax.naming.NamingException;
import javax.xml.ws.WebServiceContext;

import org.apache.log4j.Logger;

import jp.co.argo21.nautica.workflow.omg.WorkflowException;
import jp.co.argo21.nautica.workflow.soap.message.Organization;
import jp.co.argo21.nautica.workflow.soap.message.Role;
import jp.co.argo21.nautica.workflow.soap.message.User;
import jp.co.argo21.nautica.workflow.util.StringManager;

@WebService(serviceName = "RoleManager",
        portName="RoleManagerPort",
        endpointInterface = "jp.co.argo21.nautica.workflow.soap.RoleManager",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap",
        wsdlLocation = "WEB-INF/wsdl/RoleManager.wsdl")
public class RoleManagerSoapBindingImpl implements RoleManager {

	/** ログ出力用オブジェクト */
	private static Logger log = Logger.getLogger(
			RoleManagerSoapBindingImpl.class);
	
	@Resource
    private WebServiceContext context;
	
	/**
	 * 組織に付与されている全権限を返す。
	 *
	 * @param org 組織単位
	 * @return 権限の一覧
	 * @throws WorkflowException 
	 */
	@Override
	public Role[] getAttachedRoles(Organization org) throws WorkflowException {
		
		String I1004 = StringManager.get("I1004")
			+ "(Organization=" + org + ")";
		log.info(I1004);
		
		jp.co.argo21.nautica.workflow.security.Role[] role = null;
		try {
			jp.co.argo21.nautica.workflow.security.RoleManager roleManager = SingletonServices.getInstance().getRoleManager();
			role = roleManager.getAttachedRoles(org.toDataaccessOrganizationBean());
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1023");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1007 = StringManager.get("I1007") 
			+ "(Role=" + role + ")";
		log.info(I1007);
		return SoapMessageConverter.convertToSoapMessage(role);
		
	}

	/**
	 * ユーザに付与されている全権限を返す。
	 *
	 * @param user ユーザ
	 * @return 権限の一覧
	 * @throws WorkflowException 
	 */
	@Override
	public Role[] getAttachedRoles(User user) throws WorkflowException {
		
		String I1004 = StringManager.get("I1004")
			+ "(User=" + user + ")";
		log.info(I1004);
		
		jp.co.argo21.nautica.workflow.security.Role[] role = null;
		try {
			jp.co.argo21.nautica.workflow.security.RoleManager roleManager = SingletonServices.getInstance().getRoleManager();
			role = roleManager.getAttachedRoles(user.toDataaccessUserBean());
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1023");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1007 = StringManager.get("I1007") 
			+ "(Role=" + role + ")";
		log.info(I1007);
		return SoapMessageConverter.convertToSoapMessage(role);
		
	}

	/**
	 * 権限を持つ全組織単位を返す。
	 *
	 * @param role 権限
	 * @return 組織単位の一覧
	 * @throws WorkflowException 
	 */
	@Override
	public Organization[] getOrganizationsByRole(Role role) throws WorkflowException {
		
		String I1004 = StringManager.get("I1004")
			+ "(Role=" + role + ")";
		log.info(I1004);
		
		jp.co.argo21.nautica.workflow.security.Organization[] org = null;
		try {
			jp.co.argo21.nautica.workflow.security.RoleManager roleManager = SingletonServices.getInstance().getRoleManager();
			org = roleManager.getOrganizationsByRole(role.toDataaccessRoleBean());
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1009");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1007 = StringManager.get("I1007") 
			+ "(Organization=" + org + ")";
		log.info(I1007);
		return SoapMessageConverter.convertToSoapMessage(org);
		
	}

	/**
	 * ridに対応する権限を返す。
	 *
	 * @param rid 権限ID
	 * @return 権限
	 * @throws WorkflowException 
	 */
	@Override
	public Role getRole(String rid) throws WorkflowException {
		
		String I1004 = StringManager.get("I1004")
			+ "(RoleInstanceID=" + rid + ")";
		log.info(I1004);
		
		jp.co.argo21.nautica.workflow.security.Role role = null;
		try {
			jp.co.argo21.nautica.workflow.security.RoleManager roleManager = SingletonServices.getInstance().getRoleManager();
			role = roleManager.getRole(rid);
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1022");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1007 = StringManager.get("I1007") 
			+ "(Role=" + role + ")";
		log.info(I1007);
		return new jp.co.argo21.nautica.workflow.soap.message.Role(role);
		
	}

	/**
	 * 権限を持つ全ユーザを返す。
	 *
	 * @param role 権限
	 * @return ユーザの一覧
	 * @throws WorkflowException 
	 */
	@Override
	public User[] getUsersByRole(Role role) throws WorkflowException {

		String I1004 = StringManager.get("I1004")
			+ "(Role=" + role + ")";
		log.info(I1004);
		
		jp.co.argo21.nautica.workflow.security.User[] user = null;
 		try {
 			jp.co.argo21.nautica.workflow.security.RoleManager roleManager = SingletonServices.getInstance().getRoleManager();
			user = roleManager.getUsersByRole(role.toDataaccessRoleBean());
		} catch (NamingException e) {
			String errMsg = StringManager.get("E1009");
			log.error(errMsg, e);
			throw new ServiceAccessorException(errMsg);
		}
		
		String I1007 = StringManager.get("I1007") 
			+ "(User=" + user + ")";
		log.info(I1007);
		return SoapMessageConverter.convertToSoapMessage(user);
		
	}

	public WebServiceContext getContext() {
		return context;
	}
	
}