package jp.co.argo21.nautica.workflow.soap;

import javax.annotation.Resource;
import javax.jws.WebService;
import javax.xml.ws.WebServiceContext;

import org.apache.log4j.Logger;

import jp.co.argo21.nautica.workflow.util.StringManager;
import jp.co.argo21.nautica.workflow.wfmc.ConnectionFailedException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidSessionException;

@WebService(serviceName = "WorkflowServiceConnector",
        portName="WorkflowServiceConnectorPort",
        endpointInterface = "jp.co.argo21.nautica.workflow.soap.WorkflowServiceConnector",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap",
        wsdlLocation = "WEB-INF/wsdl/WorkflowServiceConnector.wsdl")
public class WorkflowServiceConnectorSoapBindingImpl implements
		WorkflowServiceConnector {

	/** ログ出力用オブジェクト */
	private static Logger log = Logger.getLogger(
			WorkflowServiceConnectorSoapBindingImpl.class);
	
	@Resource
    private WebServiceContext context;
	
	/**
	 * ワークフローエンジンへの接続認証を行い、
	 * セッションIDを取得する。
	 *
	 * @param user ユーザID
	 * @param pass パスワード
	 * @return セッションID
	 * @throws ConnectionFailedException 接続認証に失敗した場合
	 */
	@Override
	public String connect(String user, String passwd) throws ConnectionFailedException {
		
		String I4001 = StringManager.get("I4001")
			+ "(UserID=" + user + ")";
		log.info(I4001);
		
		String session = null;
		try {
			session = SingletonServices.getInstance().connectToEngine(user, passwd);
		} catch (ConnectionFailedException e) {
			String errMsg = StringManager.get("E0222");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(SessionID=" + session + ")";
   	log.info(I4002);
		return session;
		
	}
	
	/**
	 * ワークフローエンジンとの切断を行う。
	 *
	 * @param session セッションID
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 */
	@Override
	public void disconnect(String session) throws InvalidSessionException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session + ")";
		log.info(I4001);
		
		try {
			SingletonServices.getInstance().disconnectFromEngine(session);
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002");
	   log.info(I4002);
		
	}

	public WebServiceContext getContext() {
		return context;
	}
	
}