/* $Id: ParticipantHelper.java,v 1.1 2007/11/29 06:01:17 konno Exp $
 *
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow Core.
 * 
 *  Nautica Workflow Core is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow Core is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Nautica Workflow Core; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.workflow.util;

import jp.co.argo21.nautica.workflow.engine.ParticipantImpl;
import jp.co.argo21.nautica.workflow.omg.WorkflowException;
import jp.co.argo21.nautica.workflow.security.Organization;
import jp.co.argo21.nautica.workflow.security.Role;
import jp.co.argo21.nautica.workflow.security.User;
import jp.co.argo21.nautica.workflow.wfmc.Participant;

/**
 * ワークフロー参加者に関するヘルパークラスである。
 *
 * @author  nito(Argo 21, Corp.)
 * @version $Revision: 1.1 $
 * @since   Nautica Workflow 1.0
 */
public class ParticipantHelper
{
	/**
	 * ユーザをワークフロー参加者型に変換する。
	 *
	 * @param user ユーザ
	 * @return ワークフロー参加者
	 * @throws WorkflowException 変換に失敗した場合
	 */
	public static Participant narrow(User user)
	throws WorkflowException
	{
		if (user instanceof Participant) return (Participant)user;
		
		return new ParticipantImpl(user.getID(), user.getName(), Participant.HUMAN);
	}

	/**
	 * 組織をワークフロー参加者型に変換する。
	 *
	 * @param org ユーザ
	 * @return ワークフロー参加者
	 * @throws WorkflowException 変換に失敗した場合
	 */
	public static Participant narrow(Organization org)
	throws WorkflowException
	{
		if (org instanceof Participant) return (Participant)org;
		
		return new ParticipantImpl(org.getID(), org.getName(), Participant.ORGANIZATIONAL_UNIT);
	}

	/**
	 * ロールをワークフロー参加者型に変換する。
	 *
	 * @param role ロール
	 * @return ワークフロー参加者
	 * @throws WorkflowException 変換に失敗した場合
	 */
	public static Participant narrow(Role role)
	throws WorkflowException
	{
		if (role instanceof Participant) return (Participant)role;
		
		return new ParticipantImpl(role.getID(), role.getName(), Participant.ROLE);
	}
}
